==> customer-link-project-api-0.0.25-20221202.090336-3-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app87225/dto/QueryNearShopDTO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app87225.dto;

/**
 * @author zht
 * @description
 * @createTime 2022年11月30日
 */
public class QueryNearShopDTO {

    /**
     * 分页页码
     */
    private Integer current;
    /**
     * 每页条数
     */
    private Integer pageSize;
    /**
     * 主营品牌搜索
     * Nike
     * Adidas
     * Reebok
     * Puma
     * Vans
     * The North Face
     * Converse
     * Columbia
     * Asics
     * Onitsuka Tiger
     * SKECHERS
     * Timberland
     * UGG
     * Herschel
     * NBA
     * LI-NING
     */
    private String searchSaleBrand;
    /**
     * 纬度
     */
    private Long latitude;
    /**
     * longitude
     */
    private Long longitude;
    /**
     *
     */
    private String brandCode;

    public Integer getCurrent() {
        return current;
    }

    public void setCurrent(Integer current) {
        this.current = current;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public String getSearchSaleBrand() {
        return searchSaleBrand;
    }

    public void setSearchSaleBrand(String searchSaleBrand) {
        this.searchSaleBrand = searchSaleBrand;
    }

    public Long getLatitude() {
        return latitude;
    }

    public void setLatitude(Long latitude) {
        this.latitude = latitude;
    }

    public Long getLongitude() {
        return longitude;
    }

    public void setLongitude(Long longitude) {
        this.longitude = longitude;
    }

    public String getBrandCode() {
        return brandCode;
    }

    public void setBrandCode(String brandCode) {
        this.brandCode = brandCode;
    }
}

==> customer-link-project-api-1.1.50-20251011.033459-1-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app87225/dto/QueryNearShopDTO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app87225.dto;

/**
 * @author zht
 * @description
 * @createTime 2022年11月30日
 */
public class QueryNearShopDTO {

    /**
     * 分页页码
     */
    private Integer current;
    /**
     * 每页条数
     */
    private Integer pageSize;
    /**
     * 主营品牌搜索
     * Nike
     * Adidas
     * Reebok
     * Puma
     * Vans
     * The North Face
     * Converse
     * Columbia
     * Asics
     * Onitsuka Tiger
     * SKECHERS
     * Timberland
     * UGG
     * Herschel
     * NBA
     * LI-NING
     */
    private String searchSaleBrand;
    /**
     * 纬度
     */
    private Double latitude;
    /**
     * longitude
     */
    private Double longitude;
    /**
     *
     */
    private String brandCode;

    public Integer getCurrent() {
        return current;
    }

    public void setCurrent(Integer current) {
        this.current = current;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public String getSearchSaleBrand() {
        return searchSaleBrand;
    }

    public void setSearchSaleBrand(String searchSaleBrand) {
        this.searchSaleBrand = searchSaleBrand;
    }

    public Double getLatitude() {
        return latitude;
    }

    public void setLatitude(Double latitude) {
        this.latitude = latitude;
    }

    public Double getLongitude() {
        return longitude;
    }

    public void setLongitude(Double longitude) {
        this.longitude = longitude;
    }

    public String getBrandCode() {
        return brandCode;
    }

    public void setBrandCode(String brandCode) {
        this.brandCode = brandCode;
    }
}
